@@ -6,8 +6,8 @@
 # "License"); you may not use this file except in compliance
 # with the License.  You may obtain a copy of the License at
 #
-#     http://www.apache.org/licenses/LICENSE-2.0
 #
+#     http://www.apache.org/licenses/LICENSE-2.0
 #
 #
 # Unless required by applicable law or agreed to in writing,
@@ -18,12 +18,19 @@
 # under the License.
 
 from aliyunsdkcore.request import RpcRequest
+from aliyunsdkcloudauth.endpoint import endpoint_data
+
 class SubmitVerificationRequest(RpcRequest):
 
 	def __init__(self):
 		RpcRequest.__init__(self, 'Cloudauth', '2018-09-16', 'SubmitVerification','cloudauth')
 		self.set_protocol_type('https')
 		self.set_method('POST')
+		if hasattr(self, "endpoint_map"):
+			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
+		if hasattr(self, "endpoint_regional"):
+			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
+
 
 	def get_ResourceOwnerId(self):
 		return self.get_query_params().get('ResourceOwnerId')
@@ -46,13 +53,12 @@ class SubmitVerificationRequest(RpcRequest):
 	def get_Materials(self):
 		return self.get_body_params().get('Materials')
 
-	def set_Materials(self,Materials):
-		for i in range(len(Materials)):	
-			if Materials[i].get('MaterialType') is not None:
-				self.add_body_params('Material.' + str(i + 1) + '.MaterialType' , Materials[i].get('MaterialType'))
-			if Materials[i].get('Value') is not None:
-				self.add_body_params('Material.' + str(i + 1) + '.Value' , Materials[i].get('Value'))
-
+	def set_Materials(self, Materials):
+		for depth1 in range(len(Materials)):
+			if Materials[depth1].get('MaterialType') is not None:
+				self.add_body_params('Material.' + str(depth1 + 1) + '.MaterialType', Materials[depth1].get('MaterialType'))
+			if Materials[depth1].get('Value') is not None:
+				self.add_body_params('Material.' + str(depth1 + 1) + '.Value', Materials[depth1].get('Value'))
 
 	def get_TicketId(self):
 		return self.get_body_params().get('TicketId')
